<?php

/**
 * Elementor Single Widget
 * @package transpi Tools
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class Transpi_Blog extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'transpi-blog';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Blog', 'transpi-plugin' );
	}

    

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'transpi-custom-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'transpi_widgets' ];
	}

	
	protected function register_controls() {

        $this->start_controls_section(
			'int_widget_opt',
			[
				'label' => esc_html__( 'Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'style',
			[
				'label' => esc_html__( 'Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1'  => esc_html__( 'Style 1', 'transpi-plugin' ),
					'2'  => esc_html__( 'Style 2', 'transpi-plugin' ),
				]
			]
		);
		$this->add_control(
			'post_order',
			[
				'label'     => esc_html__( 'Post Order', 'transpi-plugin' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'ASC',
				'options'   => [
					'ASC'  => esc_html__( 'Ascending', 'transpi-plugin' ),
					'DESC' => esc_html__( 'Descending', 'transpi-plugin' ),
				],
			]
		);
		
		$this->add_control(
			'post_per_page',
			[
				'label'   => __( 'Posts Per Page', 'transpi-plugin' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 1,
				'default' => 5,
			]
		);
        $this->add_control(
			'post_categories',
			[
				'type'        => Controls_Manager::SELECT2,
				'label'       => esc_html__( 'Select Categories', 'transpi-plugin' ),
				'options'     => transpi_blog_category(),
				'label_block' => true,
				'multiple'    => true,
			]
		);
		$this->add_control(
			'title_length',
			[
				'label'     => __( 'Title Length', 'transpi-tools' ),
				'type'      => Controls_Manager::NUMBER,
				'step'      => 1,
				'default'   => 20,
			]
		);
				
		$this->end_controls_section();
        
	}

    protected function transpi_category_name(){

		$catgorys = get_the_category();
			
		// Shuffle the array of categories
		shuffle($catgorys);

		// Select a random category
		$random_category = array_rand($catgorys, 1);
		$category = $catgorys[$random_category];

		$meta = get_term_meta($category->term_id, 'barfii_cate_meta', true);
		$catemeta = !empty( $meta['cate-color'] )? $meta['cate-color'] : '#3b60fe';
		?>
		<a class="cate__btn" href="<?php echo esc_url(get_category_link($category->term_id)); ?>">
			<span><?php echo esc_html($category->cat_name); ?></span> 
		</a>
		<?php
    }


	protected function render() {
	$settings = $this->get_settings_for_display(); 

    $args = array(
        'post_type'           => 'post',
        'posts_per_page'      => !empty( $settings['post_per_page'] ) ? $settings['post_per_page'] : 1,
        'post_status'         => 'publish',
        'ignore_sticky_posts' => 1,
        'order'               => $settings['post_order'],
    );
    if( ! empty($settings['post_categories'] ) ){
        $args['category_name'] = implode(',', $settings['post_categories']);
    }
    
    $query = new \WP_Query( $args );
	require __DIR__ . '/template-view/blog/blog-' . $settings['style'] . '.php';
    ?>	
         
    <?php
    }
		
	
}


Plugin::instance()->widgets_manager->register( new Transpi_Blog() );