<?php

/**
 * Elementor Single Widget
 * @package transpi Tools
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class Transpi_Hero extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'transpi-hero';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Hero', 'transpi-plugin' );
	}

    

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'transpi-custom-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'transpi_widgets' ];
	}

	
	protected function register_controls() {

        $this->start_controls_section(
			'int_widget_opt',
			[
				'label' => esc_html__( 'Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
        
		$this->add_control(
			'hero_img', [
				'label' => esc_html__( 'Hero Image', 'transpi-plugin' ),
				'type' => Controls_Manager::MEDIA,
                'label_block' => true,
			]
		);
        $this->add_control(
			'subtitle', [
				'label' => esc_html__( 'Sub Title', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
        
        $this->add_control(
			'title', [
				'label' => esc_html__( 'Title', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
			]
		);
        $this->add_control(
			'btn_label', [
				'label' => esc_html__( 'Button Label', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
        $this->add_control(
			'btn_link', [
				'label' => esc_html__( 'Button Link', 'transpi-plugin' ),
				'type' => Controls_Manager::URL,
                'label_block' => true,
			]
		);
        $this->add_control(
			'call_icon', [
				'label' => esc_html__( 'Call Icon', 'transpi-plugin' ),
				'type' => Controls_Manager::ICONS,
                'label_block' => true,
			]
		);
        $this->add_control(
			'call_title', [
				'label' => esc_html__( 'Call Title', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
        $this->add_control(
			'phone', [
				'label' => esc_html__( 'Phone', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
        $this->add_control(
			'call_link', [
				'label' => esc_html__( 'Cll Link', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
				
		$this->end_controls_section();

		$this->start_controls_section(
			'widget_con_style',
			[
				'label' => esc_html__( 'Style', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'f_title',
			[
				'label' => esc_html__( 'Title Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
        $this->add_control(
			'f_title_color',
			[
				'label' => esc_html__( 'Title Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-sec-title' => 'color: {{VALUE}}'
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'title_gd_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-slider-item-content .slider-item-text .ptx-section-title-4 .ptx-sec-title span
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Title Gradient Color ', 'gesto-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'gesto-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'f_title_typography',
				'selector' => '{{WRAPPER}} .ptx-sec-title',
			]
		);

		$this->add_control(
			'sub_title',
			[
				'label' => esc_html__( 'Sub Title Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'subtitle_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-section-title-4.ver_2 .ptx-subtitle span,
					{{WRAPPER}} .ptx-section-title-4.ver_2 .ptx-subtitle:before, .ptx-section-title-4.ver_2 .ptx-subtitle:after,
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Sub Title Color ', 'gesto-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'gesto-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sub_typography',
				'selector' => '
				{{WRAPPER}} .ptx-subtitle span',
			]
		);

		$this->add_control(
			'desc_style',
			[
				'label' => esc_html__( 'Desc Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'desc_color',
			[
				'label' => esc_html__( 'Description Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-main-slider-5 .swiper-slide-active .ptx-slider-item-content .slider-item-text p' => 'color: {{VALUE}}',
					'{{WRAPPER}} .ptx-main-slider-item-6 .slider-text-area p' => 'color: {{VALUE}}'
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'count_typography',
				'selector' => '
				{{WRAPPER}} .ptx-main-slider-5 .swiper-slide-active .ptx-slider-item-content .slider-item-text p,
				{{WRAPPER}} .ptx-main-slider-item-6 .slider-text-area p
				',
			]
		);
        $this->add_control(
			'btn_style',
			[
				'label' => esc_html__( 'Button Style Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'btn_bg_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a, .slider-video-btn i, .slider-video-btn.ver_2 i
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Button BG Color ', 'gesto-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'gesto-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		$this->add_control(
			'btn__color',
			[
				'label' => esc_html__( 'Button Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a' => 'color: {{VALUE}}'
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'btn_typography',
				'selector' => '
				{{WRAPPER}} .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a',
			]
		);
        $this->add_control(
			'nivatig_style',
			[
				'label' => esc_html__( 'Slider Arrwo Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'slide_arrwo_bg',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-main-arrow-next-prev .ptx-slider-arrow:hover:before, .ptx-main-arrow-next-prev .swiper-main-paginations .swiper-pagination-bullet.swiper-pagination-bullet-active, .ptx-main-arrow-next-prev .swiper-main-pagination2 .swiper-pagination-bullet.swiper-pagination-bullet-active
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Button BG Color ', 'gesto-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'gesto-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
        $this->add_control(
			'social_style',
			[
				'label' => esc_html__( 'Social Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'btn_border_color',
			[
				'label' => esc_html__( 'Border Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-slider-social li a' => 'border-color: {{VALUE}}'
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'slide_social_icon_bg',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-slider-social li a i
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Social Icon Color ', 'gesto-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'gesto-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		
		$this->end_controls_section();
        
	}


	protected function render() {
		$settings = $this->get_settings_for_display(); ?>	
        <section class="transpi__hero-area">
            <div class="container">
                <div class="row">
                    <div class="col-lg-8 offset-lg-2">
                        <div class="content__hero text-center">
                            <?php if(!empty($settings['subtitle'])):?>
                            <span class="spilit__enable split-in-rotate"><?php echo wp_kses($settings['subtitle'], true);?></span>
                            <?php endif;?>
                            <h1 class="rts_hero__title spilit__enable split-in-right"><?php echo wp_kses($settings['title'], true);?></h1>
                            <?php if(!empty($settings['description'])):?>
                            <p><?php echo wp_kses($settings['description'], true);?></p>
                            <?php endif;?>
                            <div class="slider__btm-box">
                                <?php if(!empty($settings['btn_label'])):?>
                                <a class="thm__btn thm__btn-border" href="<?php echo esc_url($settings['btn_link']['url']);?>"><?php echo esc_html($settings['btn_label']);?> <svg xmlns="http://www.w3.org/2000/svg" width="9" height="9" viewBox="0 0 9 9" fill="none">
                                <path d="M7.63505 1.99982L2.43746 1.13948L7.63505 1.99982ZM7.63505 1.99982L7.57977 7.26784L7.63505 1.99982ZM7.63505 1.99982L1.5067 7.14212L7.63505 1.99982Z" fill="white"/>
                                <path d="M7.63505 1.99982L2.43746 1.13948M7.63505 1.99982L7.57977 7.26784M7.63505 1.99982L1.5067 7.14212" stroke="white" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"/>
                                </svg></a>
                                <?php endif;?>
                                <div class="slider-phnoe">
                                    <div class="icon">
                                    <?php \Elementor\Icons_Manager::render_icon( $settings['call_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                                    </div>
                                    <div class="text">
                                        <h4><?php echo esc_html($settings['call_title']);?></h4>
                                        <h3><a href="<?php echo $settings['call_link'];?>"><?php echo esc_html($settings['phone']);?></a></h3>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="slider__img-txt wow fadeInRight"  data-wow-delay="500ms" data-wow-duration="1000ms">
                <img src="<?php echo esc_url($settings['hero_img']['url']); ?>" alt="">
            </div>
        </section>
    <?php
    }
		
	
}


Plugin::instance()->widgets_manager->register( new Transpi_Hero() );