<?php

/**
 * Elementor Single Widget
 * @package transpi Tools
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class Transpi_Pricing_Table extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'transpi-pc-table';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Pricing Table', 'transpi-plugin' );
	}

    

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'transpi-custom-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'transpi_widgets' ];
	}

	
	protected function register_controls() {

        $this->start_controls_section(
			'int_widget_opt',
			[
				'label' => esc_html__( 'Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'dur', [
				'label' => esc_html__( 'Animation Duration', 'transpi-plugin' ),
				'placeholder' => esc_html__( '200ms', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);	
		$this->add_control(
			'active',
			[
				'label' => esc_html__( 'Active', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'YES', 'textdomain' ),
				'label_off' => esc_html__( 'NO', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
			'shape', [
				'label' => esc_html__( 'Shape', 'transpi-plugin' ),
				'type' => Controls_Manager::MEDIA,
                'label_block' => true,
			]
		);
		$this->add_control(
			'title', [
				'label' => esc_html__( 'Title', 'transpi-plugin' ),
				'default' => esc_html__( 'Personal', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
		$this->add_control(
			'price', [
				'label' => esc_html__( 'Price', 'transpi-plugin' ),
                'default' => esc_html__( '$129', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
		$this->add_control(
			'period', [
				'label' => esc_html__( 'Period', 'transpi-plugin' ),
				'default' => esc_html__( 'Per Parcel', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
        $repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'title', [
				'label' => esc_html__( 'Title', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);	
        $this->add_control(
			'lists',
			[
				'label' => esc_html__( 'Add List Item', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
                'default' => [
					[
						'title' => esc_html__( 'Comfortable vehicles, drivers', 'transpi-plugin' ),
					],
					[
						'title' => esc_html__( 'Reliable rides & assistance', 'transpi-plugin' ),
					],
					[
						'title' => esc_html__( 'Flexible booking choices', 'transpi-plugin' ),
					],
					[
						'title' => esc_html__( 'Accessible customer service', 'transpi-plugin' ),
					],
					[
						'title' => esc_html__( 'Loyalty rewards program', 'transpi-plugin' ),
					],
					[
						'title' => esc_html__( '24 Live customer support', 'transpi-plugin' ),
					],
				],
                'title_field' => '{{{ title }}}',
			]
		);
        $this->add_control(
			'btn_label', [
				'label' => esc_html__( 'Button Label', 'transpi-plugin' ),
				'default' => esc_html__( 'Sign Up', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
        $this->add_control(
			'btn_link', [
				'label' => esc_html__( 'Button Link', 'transpi-plugin' ),
				'type' => Controls_Manager::URL,
                'label_block' => true,
			]
		);
		$this->end_controls_section();
        
	}


	protected function render() {
	$settings = $this->get_settings_for_display(); 
    ?>	
        <div class="pricing__item <?php if($settings['active'] == 'yes'){ echo esc_attr('active');}?> wow fadeInUp" <?php if(!empty($settings['dur'])):?> data-wow-delay="<?php echo esc_attr($settings['dur']);?>" <?php endif;?> data-wow-duration="1000ms">
			<?php if(!empty($settings['shape']['url'])):?>
				<span class="pricing-shape"><img src="<?php echo esc_url($settings['shape']['url']);?>" alt=""></span>
			<?php endif;?>
            <div class="pricing__head">
                <h4><?php echo esc_html($settings['title']);?></h4>
                <h1><?php echo esc_html($settings['price']);?> <span><?php echo esc_html($settings['period']);?></span></h1>
            </div>
			<?php if(!empty($settings['lists'])):?>
            <ul>
				<?php foreach($settings['lists'] as $item):?>
                <li><?php echo esc_html($item['title']);?></li>
				<?php endforeach;?>
            </ul>
			<?php endif;?>
			<?php if(!empty($settings['btn_label'])):?>
            	<div class="pricin-btn text-center">
					<a class="thm__btn thm__btn-border" href="<?php echo esc_url($settings['btn_link']['url']);?>"><?php echo esc_html($settings['btn_label']);?></a>
				</div>
			<?php endif;?>
        </div>
    <?php
    }
		
	
}


Plugin::instance()->widgets_manager->register( new Transpi_Pricing_Table() );