<?php

/**
 * Elementor Single Widget
 * @package transpi Tools
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class Transpi_Service_List extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'transpi-service-list';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service List', 'transpi-plugin' );
	}

    

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'transpi-custom-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'transpi_widgets' ];
	}

	
	protected function register_controls() {

        $this->start_controls_section(
			'int_widget_opt',
			[
				'label' => esc_html__( 'Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
		$repeater = new \Elementor\Repeater();
        $repeater->add_control(
			'title', [
				'label' => esc_html__( 'Title', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
			]
		);
        $repeater->add_control(
			'link', [
				'label' => esc_html__( 'Link', 'transpi-plugin' ),
				'type' => Controls_Manager::URL,
                'label_block' => true,
			]
		);
        
        $this->add_control(
			'services',
			[
				'label' => esc_html__( 'Add Project Item', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
			]
		);		
				
		$this->end_controls_section();

		$this->start_controls_section(
			'widget_con_style',
			[
				'label' => esc_html__( 'Style', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'f_title',
			[
				'label' => esc_html__( 'Title Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
        $this->add_control(
			'f_title_color',
			[
				'label' => esc_html__( 'Title Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-sec-title' => 'color: {{VALUE}}'
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'title_gd_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-slider-item-content .slider-item-text .ptx-section-title-4 .ptx-sec-title span
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Title Gradient Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'f_title_typography',
				'selector' => '{{WRAPPER}} .ptx-sec-title',
			]
		);

		$this->add_control(
			'sub_title',
			[
				'label' => esc_html__( 'Sub Title Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'subtitle_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-section-title-4.ver_2 .ptx-subtitle span,
					{{WRAPPER}} .ptx-section-title-4.ver_2 .ptx-subtitle:before, .ptx-section-title-4.ver_2 .ptx-subtitle:after,
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Sub Title Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sub_typography',
				'selector' => '
				{{WRAPPER}} .ptx-subtitle span',
			]
		);

		$this->add_control(
			'desc_style',
			[
				'label' => esc_html__( 'Desc Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'desc_color',
			[
				'label' => esc_html__( 'Description Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-main-slider-5 .swiper-slide-active .ptx-slider-item-content .slider-item-text p' => 'color: {{VALUE}}',
					'{{WRAPPER}} .ptx-main-slider-item-6 .slider-text-area p' => 'color: {{VALUE}}'
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'count_typography',
				'selector' => '
				{{WRAPPER}} .ptx-main-slider-5 .swiper-slide-active .ptx-slider-item-content .slider-item-text p,
				{{WRAPPER}} .ptx-main-slider-item-6 .slider-text-area p
				',
			]
		);
        $this->add_control(
			'btn_style',
			[
				'label' => esc_html__( 'Button Style Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'btn_bg_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a, .slider-video-btn i, .slider-video-btn.ver_2 i
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Button BG Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		$this->add_control(
			'btn__color',
			[
				'label' => esc_html__( 'Button Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a' => 'color: {{VALUE}}'
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'btn_typography',
				'selector' => '
				{{WRAPPER}} .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a',
			]
		);
        $this->add_control(
			'nivatig_style',
			[
				'label' => esc_html__( 'Slider Arrwo Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'slide_arrwo_bg',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-main-arrow-next-prev .ptx-slider-arrow:hover:before, .ptx-main-arrow-next-prev .swiper-main-paginations .swiper-pagination-bullet.swiper-pagination-bullet-active, .ptx-main-arrow-next-prev .swiper-main-pagination2 .swiper-pagination-bullet.swiper-pagination-bullet-active
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Button BG Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
        $this->add_control(
			'social_style',
			[
				'label' => esc_html__( 'Social Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'btn_border_color',
			[
				'label' => esc_html__( 'Border Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-slider-social li a' => 'border-color: {{VALUE}}'
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'slide_social_icon_bg',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-slider-social li a i
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Social Icon Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		
		$this->end_controls_section();
        
	}


	protected function render() {
		$settings = $this->get_settings_for_display(); ?>	
		<div class="services__list-wrapper">
            <ul>
                <?php foreach($settings['services'] as $item):?>
                    <li><a href="<?php echo esc_url($item['link']['url']);?>"><?php echo esc_html($item['title']);?> <i class="far fa-long-arrow-right"></i></a></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php
    }
		
	
}


Plugin::instance()->widgets_manager->register( new Transpi_Service_List() );