<?php

/**
 * Elementor Single Widget
 * @package transpi Tools
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class Transpi_Team_Carousel extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'transpi-team-carousel';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Team Carousel', 'transpi-plugin' );
	}

    

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'transpi-custom-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'transpi_widgets' ];
	}

	
	protected function register_controls() {

        $this->start_controls_section(
			'int_widget_opt',
			[
				'label' => esc_html__( 'Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
			'title', [
				'label' => esc_html__( 'Title', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);	
        $repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'dur', [
				'label' => esc_html__( 'Animation Duration', 'transpi-plugin' ),
				'placeholder' => esc_html__( '200ms', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
		$repeater->add_control(
			'team_img', [
				'label' => esc_html__( 'Team Image', 'transpi-plugin' ),
				'type' => Controls_Manager::MEDIA,
                'label_block' => true,
			]
		);	
		$repeater->add_control(
			'title', [
				'label' => esc_html__( 'Name', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);	
		$repeater->add_control(
			'designation', [
				'label' => esc_html__( 'Designation', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);	
		$repeater->add_control(
			'link', [
				'label' => esc_html__( 'Link To Single Page', 'transpi-plugin' ),
				'type' => Controls_Manager::URL,
                'label_block' => true,
			]
		);	
        $repeater->add_control(
            'socials',
            [
                'label' => __('Social Links', 'transpi-plugin'),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    // social icon
                    [
                        'name' => 'title',
                        'label' => __('Social Title', 'transpi-plugin'),
                        'type' => Controls_Manager::TEXT,
                    ],
                    [
                        'name' => 'icon',
                        'label' => __('Social Icon', 'transpi-plugin'),
                        'type' => Controls_Manager::ICONS,
                        'default' => [
                            'value' => 'fab fa-facebook-f',
                            'library' => 'fa-solid',
                        ],
                    ],
                    // social link
                    [
                        'name' => 'link',
                        'label' => __('Social Link', 'transpi-plugin'),
                        'type' => Controls_Manager::URL,
                        'placeholder' => __('https://your-link.com', 'transpi-plugin'),
                        'default' => [
                            'url' => '#',
                        ],
                    ],
                ],
            ],
        );
        $this->add_control(
			'teams',
			[
				'label' => esc_html__( 'Add Team Item', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
			]
		);	
		$this->end_controls_section();
        
	}


	protected function render() {
	$settings = $this->get_settings_for_display(); 
    ?>	
    <div class="thm-swiper__team-wrapper">
        <div class="swiper-container thm-swiper__team">
            <div class="team__top-wrapper d-flex justify-content-between align-items-center">
                <?php if(!empty($settings['title'])):?>
                <div class="team__title">
                    <h2><?php echo esc_html($settings['title']);?></h2>
                </div>
                <?php endif;?>
                <div class="team__arrwo">
                    <div class="test-slider-arrow tr-tm-button-next"> <i class="fal fa-angle-left"></i></div>
                    <div class="test-slider-arrow tr-tm-button-prev"> <i class="fal fa-angle-right"></i></div>
                </div>
            </div>
            <div class="swiper-wrapper">
                <?php foreach($settings['teams'] as $item):?>
                <div class="swiper-slide">
                    <div class="transpi__team-item wow fadeInUp" <?php if(!empty($item['dur'])):?> data-wow-delay="<?php echo esc_attr($item['dur']);?>" <?php endif;?> data-wow-duration="1000ms">
                        <div class="team__top">
                            <div class="team_img">
                                <img src="<?php echo esc_url($item['team_img']['url']);?>" alt="">
                            </div>
                            <div class="team_overlay">
                                <span class="tm_hover"><i class="fal fa-share-alt"></i></span>
                                <div class="social_icon">
                                    <?php foreach($item['socials'] as $icn):?>
                                        <a class="<?php if(!empty($icn['title'])){ echo esc_attr($icn['title']);}?>" href="<?php echo esc_url($icn['link']['url']);?>"><?php \Elementor\Icons_Manager::render_icon( $icn['icon'], [ 'aria-hidden' => 'true' ] ); ?></a>
                                    <?php endforeach;?>
                                </div>
                            </div>
                        </div>
                        <div class="team_content">
                            <h3><a href="<?php echo esc_url($item['link']['url']);?>"><?php echo esc_html($item['title']);?></a></h3>
                            <span><?php echo esc_html($item['designation']);?></span>
                        </div>
                    </div>
                </div>
                <?php endforeach;?>
            </div>
        </div>
    </div>
    <?php
    }
		
	
}


Plugin::instance()->widgets_manager->register( new Transpi_Team_Carousel() );