<?php

/**
 * Elementor Single Widget
 * @package transpi Tools
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class Transpi_Testimonial_Two extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'transpi-testimonial-carousel-tw';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Testimonial Carousel Two', 'transpi-plugin' );
	}

    

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'transpi-custom-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'transpi_widgets' ];
	}

	
	protected function register_controls() {

        $this->start_controls_section(
			'int_widget_opt',
			[
				'label' => esc_html__( 'Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
		
		$repeater = new \Elementor\Repeater();
        
		$repeater->add_control(
			'icon', [
				'label' => esc_html__( 'Service Icon', 'transpi-plugin' ),
				'type' => Controls_Manager::ICONS,
                'label_block' => true,
			]
		);
        
        $repeater->add_control(
			'feedback', [
				'label' => esc_html__( 'Feedback', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
			]
		);
        $repeater->add_control(
			'name', [
				'label' => esc_html__( 'Name', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
        $repeater->add_control(
			'designation', [
				'label' => esc_html__( 'Designation', 'transpi-plugin' ),
				'type' => Controls_Manager::TEXT,
                'label_block' => true,
			]
		);
        $repeater->add_control(
			'authore_img', [
				'label' => esc_html__( 'Authore Image', 'transpi-plugin' ),
				'type' => Controls_Manager::MEDIA,
                'label_block' => true,
			]
		);
        
        $this->add_control(
			'testimonial',
			[
				'label' => esc_html__( 'Add Testimonial Item', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
                'title_field' => '{{{ name }}}',
			]
		);		
				
		$this->end_controls_section();

		$this->start_controls_section(
			'widget_con_style',
			[
				'label' => esc_html__( 'Style', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'f_title',
			[
				'label' => esc_html__( 'Title Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
        $this->add_control(
			'f_title_color',
			[
				'label' => esc_html__( 'Title Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-sec-title' => 'color: {{VALUE}}'
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'title_gd_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-slider-item-content .slider-item-text .ptx-section-title-4 .ptx-sec-title span
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Title Gradient Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'f_title_typography',
				'selector' => '{{WRAPPER}} .ptx-sec-title',
			]
		);

		$this->add_control(
			'sub_title',
			[
				'label' => esc_html__( 'Sub Title Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'subtitle_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-section-title-4.ver_2 .ptx-subtitle span,
					{{WRAPPER}} .ptx-section-title-4.ver_2 .ptx-subtitle:before, .ptx-section-title-4.ver_2 .ptx-subtitle:after,
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Sub Title Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sub_typography',
				'selector' => '
				{{WRAPPER}} .ptx-subtitle span',
			]
		);

		$this->add_control(
			'desc_style',
			[
				'label' => esc_html__( 'Desc Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'desc_color',
			[
				'label' => esc_html__( 'Description Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-main-slider-5 .swiper-slide-active .ptx-slider-item-content .slider-item-text p' => 'color: {{VALUE}}',
					'{{WRAPPER}} .ptx-main-slider-item-6 .slider-text-area p' => 'color: {{VALUE}}'
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'count_typography',
				'selector' => '
				{{WRAPPER}} .ptx-main-slider-5 .swiper-slide-active .ptx-slider-item-content .slider-item-text p,
				{{WRAPPER}} .ptx-main-slider-item-6 .slider-text-area p
				',
			]
		);
        $this->add_control(
			'btn_style',
			[
				'label' => esc_html__( 'Button Style Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'btn_bg_color',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a, .slider-video-btn i, .slider-video-btn.ver_2 i
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Button BG Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		$this->add_control(
			'btn__color',
			[
				'label' => esc_html__( 'Button Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a' => 'color: {{VALUE}}'
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'btn_typography',
				'selector' => '
				{{WRAPPER}} .ptx-btn-4 a, .ptx-btn-5 a, .ptx-btn-6 a',
			]
		);
        $this->add_control(
			'nivatig_style',
			[
				'label' => esc_html__( 'Slider Arrwo Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'slide_arrwo_bg',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-main-arrow-next-prev .ptx-slider-arrow:hover:before, .ptx-main-arrow-next-prev .swiper-main-paginations .swiper-pagination-bullet.swiper-pagination-bullet-active, .ptx-main-arrow-next-prev .swiper-main-pagination2 .swiper-pagination-bullet.swiper-pagination-bullet-active
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Button BG Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
        $this->add_control(
			'social_style',
			[
				'label' => esc_html__( 'Social Style', 'transpi-plugin' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'btn_border_color',
			[
				'label' => esc_html__( 'Border Color', 'transpi-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ptx-slider-social li a' => 'border-color: {{VALUE}}'
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'slide_social_icon_bg',
				'types' => [ 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '
					{{WRAPPER}} .ptx-slider-social li a i
				',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__( 'Social Icon Color ', 'transpi-plugin' ),
                        'description' => esc_html__( 'Choose background type and style.', 'transpi-plugin' ),
                        'separator' => 'before',
                    ]
				],
			]
		);
		
		$this->end_controls_section();
        
	}

	protected function render() {
		$settings = $this->get_settings_for_display(); ?>	
        <div class="testimonial__two-wrapper">   
            <div class="thm-swiper__testimonial-two swiper-container">
                <div class="swiper-wrapper">
                    <?php foreach($settings['testimonial'] as $item):?>
                    <div class="swiper-slide">
                        <div class="testimonial__item-two">
                            <div class="testimonial_thumb">
                                <img src="<?php echo esc_url($item['authore_img']['url']);?>" alt="">
                            </div>
                            <div class="testimonial__content">
                                <svg xmlns="http://www.w3.org/2000/svg" width="72" height="72" viewBox="0 0 72 72" fill="none">
                                <circle cx="36" cy="36" r="36" fill="#FF131D"/>
                                <path fill-rule="evenodd" clip-rule="evenodd" d="M30.679 21.2619C23.1484 26.0981 18.9648 31.7271 18.1282 38.1488C16.8259 48.1459 25.7661 53.0392 30.296 48.6426C34.8259 44.246 32.1105 38.6655 28.8304 37.1401C25.5503 35.6146 23.5444 36.1459 23.8943 34.1074C24.2442 32.069 28.9108 26.4172 33.0106 23.7851C33.2826 23.5538 33.3861 23.105 33.1242 22.7645C32.9519 22.5406 32.614 22.1014 32.1105 21.447C31.6702 20.8747 31.2484 20.8962 30.679 21.2619Z" fill="white"/>
                                <path fill-rule="evenodd" clip-rule="evenodd" d="M50.5051 21.2619C42.9746 26.0981 38.791 31.7271 37.9544 38.1488C36.6521 48.1459 45.5923 53.0392 50.1222 48.6426C54.6521 44.246 51.9367 38.6655 48.6566 37.1401C45.3765 35.6146 43.3705 36.1459 43.7205 34.1074C44.0704 32.069 48.737 26.4172 52.8368 23.7851C53.1088 23.5538 53.2123 23.105 52.9503 22.7645C52.7781 22.5406 52.4402 22.1014 51.9367 21.447C51.4964 20.8747 51.0746 20.8962 50.5051 21.2619Z" fill="white"/>
                                </svg>
                                <p><?php echo wp_kses($item['feedback'], true);?></p>
                                <h4><?php echo esc_html($item['name']);?></h4>
                                <span><?php echo esc_html($item['designation']);?></span>
                            </div>
                        </div>
                    </div>
                    <?php endforeach;?>
                </div>
            </div>
            <div class="testimonial__slider-item">
                <div class="test-slider-arrow testi-sl-prev"> <i class="fal fa-angle-up"></i></div>
                <div class="test-slider-arrow testi-sl-nxt"> <i class="fal fa-angle-down"></i></div>
            </div>
        </div>
    <?php
    }
		
	
}


Plugin::instance()->widgets_manager->register( new Transpi_Testimonial_Two() );