<?php
/*
 * Theme Options
 * @package transpi
 * @since 1.0.0
 * */

if ( !defined( 'ABSPATH' ) ) {
    exit(); // exit if access directly
}

if ( class_exists( 'CSF' ) ) {

    //
    // Set a unique slug-like ID
    $prefix = 'transpi';

    //
    // Create options
    CSF::createOptions( $prefix . '_theme_options', array(
        'menu_title'         => 'Transpi Options',
        'menu_slug'          => 'transpi-theme-option',
        'menu_type'          => 'menu',
        'enqueue_webfont'    => true,
        'show_in_customizer' => true,
        'menu_icon' => 'dashicons-category',
        'menu_position' => 50,
        'theme'                   => 'light',
        'framework_title'    => wp_kses_post( 'Transpi Options' ),
        'footer_text'    => wp_kses_post( 'The Theme will Created By byteflows ' ),
    ) );

    // Create a top-tab
    CSF::createSection( $prefix . '_theme_options', array(
        'id'    => 'header_opts', // Set a unique slug-like ID
        'title' => 'Header',
    ) );


    /*-------------------------------------------------------
     ** Logo Settings  Options
    --------------------------------------------------------*/

    /*-------------------------------------------------------
     ** Header  Options
    --------------------------------------------------------*/

    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => 'General Settings',
        'id'     => 'general_settings',
        'icon'   => 'fa fa-refresh',
        'fields' => array(

            array(
                'id'      => 'preloader_enable',
                'title'   => esc_html__( 'Enable Preloader', 'transpi-tools' ),
                'type'    => 'switcher',
                'desc'    => esc_html__( 'Enable or Disable Preloader', 'transpi-tools' ),
                'default' => true,
            ),
            
            // default preloader bg color
            array(
                'id'      => 'transpi_custom_preloader',
                'title'   => esc_html__( 'Upload Preloader', 'transpi-tools' ),
                'type'    => 'media',
                'dependency' => array( 'preloader_enable', '==', 'true' ),
            ),
            array(
                'id'      => 'preloader_bg',
                'title'   => esc_html__( 'Preloader BG Color', 'transpi-tools' ),
                'type'    => 'color',
                'output'  => array(
                    'background-color' => '#transpiPreloader',
                ),
                'dependency' => array( 'preloader_enable', '==', 'true' ),
            ),
            
            array(
                'id'    => 'logo-1-width',
                'type'  => 'slider',
                'min'     => 0,
                'max'     => 5000,
                'step'    => 1,
                'unit'    => 'px',
                'title' => 'Preloader Size',
                'output'      => '#transpiPreloader .preloader__inner img',
                'output_mode' => 'max-width',
                'dependency' => array( 'preloader_enable', '==', 'true' ),
            ),
            array(
                'id'      => 'scroll_up_btn',
                'title'   => esc_html__( 'Enable Scroll Up', 'transpi-tools' ),
                'type'    => 'switcher',
                'desc'    => esc_html__( 'Enable or Disable Scroll Up', 'transpi-tools' ),
                'default' => true,
            ),
            

        ),
    ) );

    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => esc_html__( 'Header', 'transpi-tools' ),
        'parent'     => 'header_opts',
        'icon'   => 'fa fa-header',
        'fields' => array(
            array(
                'type'    => 'subheading',
                'content' => '<h3>' . esc_html__( 'Header Layout', 'transpi-tools' ) . '</h3>',
            ),

            array(
                'id'          => 'header_style',
                'type'        => 'select',
                'title'       => __('Select Header Style', 'transpi-tools' ),
                'options'     => Transpi_Plugin_Helper::get_header_types(),
            ),
            array(
                'id'      => 'transpi_logo',
                'title'   => esc_html__( 'Default Logo', 'transpi-tools' ),
                'type'    => 'media',
                'desc'    => esc_html__( 'Upload Logo', 'transpi-tools' ),
                'default' => true,
            ),
           

        ),
    ) );



   


    /*-------------------------------------
     ** Typography Options
    -------------------------------------*/
    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => esc_html__( 'Typography', 'transpi-tools' ),
        'id'     => 'typography_options',
        'icon'   => 'fa fa-font',
        'fields' => array(

            array(
                'type'    => 'subheading',
                'content' => '<h3>' . esc_html__( 'Body', 'transpi-tools' ) . '</h3>',
            ),

            array(
                'id'     => 'body-typography',
                'type'   => 'typography',
                'output' => 'body',

            ),

            array(
                'type'    => 'subheading',
                'content' => '<h3>' . esc_html__( 'Heading', 'transpi-tools' ) . '</h3>',
            ),

            array(
                'id'     => 'heading-gl-typo',
                'type'   => 'typography',
                'output' => 'h1, h2, h3, h4, h5, h6',
            ),

        ),
    ) );

    // Product
    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => esc_html__( 'Woocommerce Option', 'transpi-tools' ),
        'id'     => 'woo_option',
        'icon'   => 'fa fa-header',
        'fields' => array(
            array(
                'type'    => 'subheading',
                'content' => '<h3>' . esc_html__( 'Woocommerce Option', 'transpi-tools' ) . '</h3>',
            ),

            array(
                'id'      => 'product_count',
                'title'   => esc_html__( 'Product Count', 'transpi-tools' ),
                'type'    => 'text',
                'default' => '12',
            ),
            array(
				'id'       => 'enable_shop_preadcrumb',
				'type'     => 'switcher',
				'title'    => __( 'Page Breadcrumb', 'transpi-plugin' ),
				'text_on'  => __( 'Yes', 'transpi-plugin' ),
				'text_off' => __( 'No', 'transpi-plugin' ),
				'default'  => true
			),
            array(
                'id'      => 'shop_breadcrumb_bg',
                'title'   => esc_html__( 'Shop Breadcrumb BG', 'transpi-tools' ),
                'type'    => 'media',
                'dependency' => array( 'enable_shop_preadcrumb', '==', 'true' ),
            ),
            array(
                'id'      => 'shop_breadcrumb_title',
                'title'   => esc_html__( 'Shop Breadcrumb Title', 'transpi-tools' ),
                'type'    => 'text',
                'dependency' => array( 'enable_shop_preadcrumb', '==', 'true' ),
            ),
            array(
				'id'       => 'enable_single_product_preadcrumb',
				'type'     => 'switcher',
				'title'    => __( 'Shop Enable Breadcrumb', 'transpi-plugin' ),
				'text_on'  => __( 'Yes', 'transpi-plugin' ),
				'text_off' => __( 'No', 'transpi-plugin' ),
				'default'  => true
			),
            array(
                'id'      => 'product_single_breadcrumb_bg',
                'title'   => esc_html__( 'Product Single Breadcrumb BG', 'transpi-tools' ),
                'type'    => 'media',
                'dependency' => array( 'enable_single_product_preadcrumb', '==', 'true' ),
            ),
            array(
                'id'      => 'product_single_breadcrumb_title',
                'title'   => esc_html__( 'Shop Breadcrumb Title', 'transpi-tools' ),
                'type'    => 'text',
                'dependency' => array( 'enable_single_product_preadcrumb', '==', 'true' ),
            ),

        ),
    ) );

    // blog optoins
    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => esc_html__( 'Blog', 'transpi-tools' ),
        'id'     => 'blog_page',
        'icon'   => 'fa fa-rss-square',
        'fields' => array(

            array(
                'type'    => 'subheading',
                'content' => '<h3>' . esc_html__( 'Blog Options', 'transpi-tools' ) . '</h3>',
            ),

            array(
                'id'      => 'breadcrumb_bg_img',
                'type'    => 'media',
                'title'   => esc_html__('Breadcrumb BG', 'printox-tools'),
            ),

            array(
                'id'      => 'blog_btn_text',
                'type'    => 'text',
                'title'   => esc_html__( 'Blog Read More Button', 'transpi-tools' ),
                'default' => esc_html__( 'Explore More', 'transpi-tools' ),
                'desc'    => esc_html__( 'Type Blog Read More Button Text Here', 'transpi-tools' ),
            ),
        ),
    ) );


   // transpi Color Setting
   CSF::createSection( $prefix . '_theme_options', array(
    'title'  => 'Color Control',
    'id'     => 'apix_color_control',
    'icon'   => 'fa fa-paint-brush',
    'fields' => array(


        array(  //nav bar one start
            'type'    => 'subheading',
            'content' => '<h3>' . esc_html__( 'Theme Primary Color', 'transpi-tools' ) . '</h3>',
        ),
        array(
            'id'    => 'theme-color-1',
            'type'  => 'color',
            'title' => 'Theme Primary Color',
            'default' => '#FF131D'
        ),
        

    ),
) );

    // Create a section
    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => 'transpi Social Icon',
        'id'     => 'transpi_social_icons',
        'icon'   => 'fa fa-share-square-o',
        'fields' => array(


            array(  //nav bar one start
                'type'    => 'subheading',
                'content' => '<h3>' . esc_html__( 'Social Icon Options', 'transpi-tools' ) . '</h3>',
            ),

            array(
                'id'        => 'transpi-social-global',
                'type'      => 'repeater',
                'title'     => 'transpi Global Social',
                'subtitle'      => 'Add Social Icon And Icon Link Here',
                'fields'    => array(

                  array(
                    'id'    => 'social_icon',
                    'type'  => 'icon',
                    'title' => 'Choose Social Icon Here',
                  ),
                  array(
                    'id'    => 'social_title',
                    'type'  => 'text',
                    'title' => 'Social Title Here',
                  ),
                  array(
                    'id'    => 'social_follow_title',
                    'type'  => 'text',
                    'title' => 'Social Flow Title Here',
                  ),
                  array(
                    'id'    => 'social_link',
                    'type'  => 'text',
                    'title' => 'Social Profile Link Here',
                  ),

                ),
                'default'   => array(
                  array(
                    'social_icon' => 'fab fa-facebook-f',
                    'social_link' => '#',
                  ),
                  array(
                    'social_icon' => 'fab fa-twitter',
                    'social_link' => '#',
                  ),
                  array(
                    'social_icon' => 'fab fa-instagram',
                    'social_link' => '#',
                  ),
                  array(
                    'social_icon' => 'fab fa-youtube',
                    'social_link' => '#',
                  ),
                  array(
                    'social_icon' => 'fab fa-pinterest',
                    'social_link' => '#',
                  ),
                ),
            ),

        ),
    ) );


    // Create a section
    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => 'Error Page',
        'id'     => 'error_page',
        'icon'   => 'fa fa-exclamation-triangle',
        'fields' => array(


            array(  //nav bar one start
                'type'    => 'subheading',
                'content' => '<h3>' . esc_html__( '404 Page Options', 'transpi-tools' ) . '</h3>',
            ),

            array(
                'id'      => 'error_code',
                'type'    => 'media',
                'title'   => esc_html__( 'Error Code Image', 'transpi-tools' ),
            ),
            array(
                'id'      => 'error_title',
                'type'    => 'text',
                'title'   => esc_html__( '404 Title', 'transpi-tools' ),
                'default' => esc_html__( 'Oops! Page Not found.', 'transpi-tools' ),
            ),
            array(
                'id'      => 'error_text',
                'type'    => 'textarea',
                'title'   => esc_html__( '404 Text', 'transpi-tools' ),
                'default' => esc_html__( 'You’re either misspelling the URL or requesting a page thats no longer here.', 'transpi-tools' ),
            ),

            array(
                'id'      => 'error_button',
                'type'    => 'text',
                'title'   => esc_html__( '404 Button', 'transpi-tools' ),
                'default' => esc_html__( 'back to Home page ', 'transpi-tools' ),
            ),
            array(
                'id'      => 'br_custom_bg',
                'type'    => 'media',
                'title'   => esc_html__( '404 Breadcrumb BG Image', 'transpi-tools' ),
            ),
            array(
                'id'      => 'er_custom_title',
                'type'    => 'text',
                'title'   => esc_html__( '404 Breadcrumb Title', 'transpi-tools' ),
            ),


        ),
    ) );

    /*-------------------------------------------------------
     ** Footer  Options
    --------------------------------------------------------*/

    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => esc_html__( 'Footer Options', 'transpi-tools' ),
        'icon'   => 'fa fa-copyright',
        'fields' => array(

            array(
                'id'          => 'footer_style',
                'type'        => 'select',
                'title'       => __('Select Footer Style', 'transpi-tools' ),
                'options'     => Transpi_Plugin_Helper::get_footer_types(),
            ),

        ),
    ) );

    // Backup section
    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => esc_html__( 'Backup Export', 'transpi-tools' ),
        'id'     => 'backup_options',
        'icon'   => 'fa fa-window-restore',
        'fields' => array(
            array(
                'type' => 'backup',
            ),
        ),
    ) );




}