<?php

/**
 * Elementor Single Widget
 * @package transpi Tools
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class Transpi_Video_Popup extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'transpi-video-popup';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Video Popup', 'transpi-plugin' );
	}

    

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'transpi-custom-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'transpi_widgets' ];
	}

	
	protected function register_controls() {

        $this->start_controls_section(
			'int_widget_opt',
			[
				'label' => esc_html__( 'Option', 'transpi-plugin' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'video_banner', [
				'label' => esc_html__( 'Video Banner', 'transpi-plugin' ),
				'type' => Controls_Manager::MEDIA,
                'label_block' => true,
			]
		);
		$this->add_control(
			'video_link', [
				'label' => esc_html__( 'Video Link', 'transpi-plugin' ),
				'type' => Controls_Manager::URL,
                'label_block' => true,
			]
		);
        
		$this->end_controls_section();
        
	}


	protected function render() {
	$settings = $this->get_settings_for_display(); 
    ?>	
        <div class="transpi__video-popup">
            <img src="<?php echo esc_url($settings['video_banner']['url']);?>" alt="">
            <a href="<?php echo esc_url($settings['video_link']['url']);?>" class="video-popup"><i class="fas fa-play"></i></a>
        </div>
    <?php
    }
		
	
}


Plugin::instance()->widgets_manager->register( new Transpi_Video_Popup() );