<?php
/*
 * Theme Metabox
 * @package transpi-tools
 * @since 1.0.0
 * */

if ( !defined( 'ABSPATH' ) ) {
    exit(); // exit if access directly
}

if ( class_exists( 'CSF' ) ) {

    $prefix = 'transpi';

    /*-------------------------------------
    Page Options
    -------------------------------------*/
    $post_metabox = 'transpi_page_meta';

    CSF::createMetabox( $post_metabox, array(
        'title'     => 'Page Options',
        'post_type' => array('plan', 'page', 'post'),
    ) );

    // Header Section
    CSF::createSection( $post_metabox, array(
        'title'  => 'Header',
        'fields' => array(
            array(
                'type'    => 'subheading',
                'content' => esc_html__( 'Header Option', 'transpi-tools' ),
            ),

            array(
				'id'       => 'meta_header_type',
				'type'     => 'switcher',
				'title'    => __( 'Header Style', 'transpi-plugin' ),
				'text_on'  => __( 'Yes', 'transpi-plugin' ),
				'text_off' => __( 'No', 'transpi-plugin' ),
				'default'  => false
			),
            array(
				'id'          => 'meta_header_style',
				'type'        => 'select',
				'title'       => __('Select Header Style', 'transpi-plugin' ),
				'options'     => Transpi_Plugin_Helper::get_header_types(),
                'dependency' => array( 'meta_header_type', '==', 'true' ),
			),
            array(
				'id'       => 'page_header_disable',
				'type'     => 'switcher',
				'title'    => __( 'DIsable This page Header?', 'transpi-plugin' ),
				'text_on'  => __( 'Yes', 'transpi-plugin' ),
				'text_off' => __( 'No', 'transpi-plugin' ),
				'default'  => false
			),
        ),
    ) );

    // Breadcrumb Section
    CSF::createSection( $post_metabox, array(
        'title'  => 'Page Settings',
        'fields' => array(
            array(
                'type'    => 'subheading',
                'content' => esc_html__( 'Page Color', 'transpi-tools' ),
            ),
           
            array(
                'id'     => 'scroll-top-color',
                'type'   => 'color',
                'title'  => 'Scroll Up Button Color',
                'output' => '.back-top-btn, .hap-contact-form button, .hap-footer-widget .bi-footer-newslatter button',
                'output_mode' => 'background',
            ),
            array(
                'id'     => 'scroll-bar',
                'type'   => 'color',
                'title'  => 'Scroll Bar Color',
                'output'      => 'body::-webkit-scrollbar-thumb',
                'output_mode' => 'background',
            ),
            
        )
    ) );

    CSF::createSection( $post_metabox, array(
        'title'  => 'Page Breadcrumb',
        'fields' => array(
            array(
                'type'    => 'subheading',
                'content' => esc_html__( 'Page Breadcrumb', 'transpi-plugin' ),
            ),
            array(
				'id'       => 'enable_page_preadcrumb',
				'type'     => 'switcher',
				'title'    => __( 'Page Breadcrumb', 'transpi-plugin' ),
				'text_on'  => __( 'Yes', 'transpi-plugin' ),
				'text_off' => __( 'No', 'transpi-plugin' ),
				'default'  => true
			),
            array(
				'id'       => 'hide_bg_img',
				'type'     => 'switcher',
				'title'    => __( 'Hide Breadcrumb Page Image', 'transpi-plugin' ),
				'text_on'  => __( 'Yes', 'transpi-plugin' ),
				'text_off' => __( 'No', 'transpi-plugin' ),
				'default'  => true
			),
            array(
                'id'    => 'bg_img_from_page',
                'type'  => 'media',
                'title' => esc_html__( 'Page Breadcrumb Background Image', 'transpi-tools' ),
                'dependency' => array( 'enable_page_preadcrumb', '==', 'true' ),
                
            ),
            array(
				'id'       => 'enable_custom_title',
				'type'     => 'switcher',
				'title'    => __( 'Enable Page Custom Title', 'transpi-plugin' ),
				'text_on'  => __( 'Yes', 'transpi-plugin' ),
				'text_off' => __( 'No', 'transpi-plugin' ),
				'default'  => false
			),
            
            array(
                'id'    => 'page_custom_title',
                'type'  => 'text',
                'title' => esc_html__( 'Page Custom Title', 'transpi-tools' ),
                'dependency' => array( 'enable_custom_title', '==', 'true' ),
            ),
            
        )
    ) );
    

    // Header Section
    CSF::createSection( $post_metabox, array(
        'title'  => 'Footer',
        'fields' => array(
            array(
                'type'    => 'subheading',
                'content' => esc_html__( 'Footer Option', 'transpi-tools' ),
            ),

            array(
				'id'       => 'meta_footer_type',
				'type'     => 'switcher',
				'title'    => __( 'Footer Style', 'transpi-plugin' ),
				'text_on'  => __( 'Yes', 'transpi-plugin' ),
				'text_off' => __( 'No', 'transpi-plugin' ),
				'default'  => false
			),
            array(
				'id'          => 'meta_footer_style',
				'type'        => 'select',
				'title'       => __('Select Footer Style', 'transpi-plugin' ),
				'options'     => Transpi_Plugin_Helper::get_footer_types(),
                'dependency' => array( 'meta_footer_type', '==', 'true' ),
			),
            array(
				'id'       => 'page_footer_disable',
				'type'     => 'switcher',
				'title'    => __( 'DIsable This page Footer?', 'transpi-plugin' ),
				'text_on'  => __( 'Yes', 'transpi-plugin' ),
				'text_off' => __( 'No', 'transpi-plugin' ),
				'default'  => false
			),

        ),
    ) );

     /*-------------------------------------
    Page Options
    -------------------------------------*/
    $post_metabox = 'transpi_pricing_meta';

    CSF::createMetabox( $post_metabox, array(
        'title'     => 'Pricing Options',
        'post_type' => 'transpi_pricing',
    ) );

    // Header Section
    CSF::createSection( $post_metabox, array(
        'title'  => 'transpi Pricing Table ',
        'fields' => array(
            array(
                'id'      => 'populer_item',
                'type'    => 'checkbox',
                'title'   => 'Select Populer Item',
                'label'   => 'If you want to Populer Item then please check the box',
                'default' => false // or false
            ),
            array(
                'id'    => 'offer_text',
                'type'  => 'text',
                'title' => esc_html__( 'Offer Text', 'transpi-tools' ),
            ),
            array(
                'id'    => 'currency',
                'type'  => 'text',
                'title' => esc_html__( 'Currency', 'transpi-tools' ),
                'default' => '$',
            ),
            array(
                'id'    => 'monthly_price',
                'type'  => 'text',
                'title' => esc_html__( 'Monthly Price ', 'transpi-tools' ),
            ),
            array(
                'id'    => 'yearly_price',
                'type'  => 'text',
                'title' => esc_html__( 'Yearly Price ', 'transpi-tools' ),
            ),
            array(
                'id'    => 'mon_period',
                'type'  => 'text',
                'title' => esc_html__( 'Monthly Period ', 'transpi-tools' ),
                'default' => esc_html__( '/ Monthly', 'transpi-tools' ),
            ),
            array(
                'id'    => 'yr_period',
                'type'  => 'text',
                'title' => esc_html__( 'Yearly Period ', 'transpi-tools' ),
                'default' => esc_html__( '/ Yearly', 'transpi-tools' ),
            ),
            array(
                'id'         => 'pricing_lists',
                'type'       => 'group',
                'title'      => 'Add Pricing List Item',
                'fields'     => array(
                    
                    array(
                        'id'    => 'list-item',
                        'type'  => 'text',
                        'title' => esc_html__( 'Pricing List Item', 'transpi-tools' ),
                    ),
                    array(
                        'id'      => 'exclude-in-package',
                        'title'   => esc_html__( 'Exclude In This Package', 'transpi-tools' ),
                        'type'    => 'switcher',
                        'default' => false,
                    ),
                )

            ),
            array(
                'id'    => 'pricing_btn',
                'type'  => 'link',
                'title' => esc_html__( 'Pricing Button', 'transpi-tools' ),
            ),
            array(
                'id'    => 'pricing_txt',
                'type'  => 'text',
                'title' => esc_html__( 'Pricing Text', 'transpi-tools' ),
            ),

        ),
    ) );

    /*-------------------------------------
    Page Options
    -------------------------------------*/
    $post_metabox = 'transpi_career_meta';

    CSF::createMetabox( $post_metabox, array(
        'title'     => 'Career Options',
        'post_type' => 'transpi_career',
    ) );

    // Header Section
    CSF::createSection( $post_metabox, array(
        'fields' => array(
            
            array(
                'id'    => 'icon',
                'type'  => 'icon',
                'title' => esc_html__( 'Job Icon', 'transpi-tools' ),
            ),
           
            array(
                'id'    => 'job_type',
                'type'  => 'text',
                'title' => esc_html__( 'Job Type', 'transpi-tools' ),
                'desc' => esc_html__( 'Job Type Means Full Time Job or Part Time Job', 'transpi-tools' ),
            ),
            array(
                'id'    => 'job_location',
                'type'  => 'text',
                'title' => esc_html__( 'Job Location', 'transpi-tools' ),
                'desc' => esc_html__( 'Type Yor Job Location', 'transpi-tools' ),
            ),
            array(
                'id'    => 'job_date',
                'type'  => 'date',
                'title' => esc_html__( 'Job Date', 'transpi-tools' ),
                'desc' => esc_html__( 'Type Yor Job Ending Date Here', 'transpi-tools' ),
            ),
            array(
                'id'    => 'job_salary',
                'type'  => 'text',
                'title' => esc_html__( 'Job Salary', 'transpi-tools' ),
                'desc' => esc_html__( 'Type Yor Job Salary Range Here', 'transpi-tools' ),
            ),
            array(
                'id'    => 'job_excerpt',
                'type'  => 'textarea',
                'title' => esc_html__( 'Job Excerpt', 'transpi-tools' ),
                'desc' => esc_html__( 'Type Yor Job Short Description Here', 'transpi-tools' ),
            ),
        ),
    ) );



    /*-------------------------------------
    Page Options
    -------------------------------------*/
    $transpi_temp_meta = 'transpi_temp_meta';

    CSF::createMetabox( $transpi_temp_meta, array(
        'title'     => 'Template Type',
        'post_type' => array('transpi_template'),
        'data_type' => 'unserialize'
    ) );

     // Header Section
     CSF::createSection( $transpi_temp_meta, array(
        'fields' => array(
            array(
                'id'          => 'transpi_template_type',
                'type'        => 'select',
                'title'       => 'Select Template Type',
                'placeholder' => 'Select Template Type',
                'options'     => array(
                  'tf_header_key'  => 'Header',
                  'tf_footer_key'  => 'Footer',
                ),
                'default'     => ''
            ),
        ),
    ) );


    /*-------------------------------------
    Portfolio Options
    -------------------------------------*/
    $transpi_port_meta = 'transpi_portfolio_meta';

    CSF::createMetabox( $transpi_port_meta, array(
        'title'     => 'Portfolio Option',
        'post_type' => array('transpi_portfolio'),
    ) );

     // Header Section
     CSF::createSection( $transpi_port_meta, array(
        'fields' => array(
            array(
                'id'          => 'port-column',
                'type'        => 'select',
                'title'       => 'Select Portfolio Column',
                'options'     => array(
                  '12'  => 'Full Column',
                  '6'   => 'Two Column',
                  '3'   => 'Four Column',
                  '4'   => 'Three Column',
                ),
                'default'     => '12'
            ),
            array(
                'id'    => 'cl_no',
                'type'  => 'text',
                'title' => esc_html__( 'Job Salary', 'transpi-tools' ),
                'desc' => esc_html__( 'Type Yor Job Salary Range Here', 'transpi-tools' ),
            ),
        ),
    ) );


    
    

} //endif
