<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package transpi
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function transpi_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'transpi_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function transpi_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'transpi_pingback_header' );

function animated_line(){ 
if(get_post_meta(get_the_ID(), 'transpi_page_meta', true)) {
	$page_meta = get_post_meta(get_the_ID(), 'transpi_page_meta', true);
} else {
	$page_meta = array();
}

if( array_key_exists( 'page_line_style', $page_meta )) {
	$page_line_style = $page_meta['page_line_style'];
} else {
	$page_line_style = '1';
}
?>
	<div class="vertical-lines-wrapper <?php if($page_line_style != 1){ echo esc_attr('alternate');}?>">
        <div class="vertical-lines <?php if($page_line_style != 1){ echo esc_attr('light');}?>">
			<div class="vertical-effect"></div>
			<div class="vertical-effect"></div>
			<div class="vertical-effect"></div>
			<div class="vertical-effect"></div>
			<div class="vertical-effect"></div>
			<div class="vertical-effect"></div>
			<div class="vertical-effect"></div>
			<div class="vertical-effect"></div>
		</div>
	</div>
<?php
}

/**
 * Breadcrumb
 *
 * @return  [type]  [return description]
 */
function transpi_the_breadcrumb() {
	global $wp_query;
	$queried_object = get_queried_object();
	$breadcrumb     = '';
	$delimiter      = '';
	$before         = '<li class="breadcrumb-item">';
	$after          = '</li>';
	if ( ! is_front_page() ) {
		$breadcrumb .= $before . '<a href="' . home_url( '/' ) . '">' . esc_html__( 'Home', 'transpi' ) . ' &nbsp;</a>' . $after;
		/** If category or single post */
		if ( is_category() ) {
			$cat_obj       = $wp_query->get_queried_object();
			$this_category = get_category( $cat_obj->term_id );
			if ( $this_category->parent != 0 ) {
				$parent_category = get_category( $this_category->parent );
				$breadcrumb      .= get_category_parents( $parent_category, true, $delimiter );
			}
			$breadcrumb .= $before . '<a href="' . get_category_link( get_query_var( 'cat' ) ) . '">' . single_cat_title( '', false ) . '</a>' . $after;
		} elseif ( $wp_query->is_posts_page ) {
			$breadcrumb .= $before . $queried_object->post_title . $after;
		} elseif ( is_tax() ) {
			$breadcrumb .= $before . '<a href="' . get_term_link( $queried_object ) . '">' . $queried_object->name . '</a>' . $after;
		} elseif ( is_page() ) /** If WP pages */ {
			global $post;
			if ( $post->post_parent ) {
				$anc = get_post_ancestors( $post->ID );
				foreach ( $anc as $ancestor ) {
					$breadcrumb .= $before . '<a href="' . get_permalink( $ancestor ) . '">' . get_the_title( $ancestor ) . ' &nbsp;</a>' . $after;
				}
				$breadcrumb .= $before . '' . get_the_title( $post->ID ) . '' . $after;
			} else {
				$breadcrumb .= $before . '' . get_the_title() . '' . $after;
			}
		} elseif ( is_singular() ) {
			if ( $category = wp_get_object_terms( get_the_ID(), array( 'category', 'location', 'tax_feature' ) ) ) {
				if ( ! is_wp_error( $category ) ) {
					$breadcrumb .= $before . '<a href="' . get_term_link( transpi_set( $category, '0' ) ) . '">' . transpi_set( transpi_set( $category, '0' ), 'name' ) . '&nbsp;</a>' . $after;
					$breadcrumb .= $before . '' . get_the_title() . '' . $after;
				} else {
					$breadcrumb .= $before . '' . get_the_title() . '' . $after;
				}
			} else {
				$breadcrumb .= $before . '' . get_the_title() . '' . $after;
			}
		} elseif ( is_tag() ) {
			$breadcrumb .= $before . '<a href="' . get_term_link( $queried_object ) . '">' . single_tag_title( '', false ) . '</a>' . $after;
		} /**If tag template*/
		elseif ( is_day() ) {
			$breadcrumb .= $before . '<a href="#">' . esc_html__( 'Archive for ', 'transpi' ) . get_the_time( 'F jS, Y' ) . '</a>' . $after;
		} /** If daily Archives */
		elseif ( is_month() ) {
			$breadcrumb .= $before . '<a href="' . get_month_link( get_the_time( 'Y' ), get_the_time( 'm' ) ) . '">' . __( 'Archive for ', 'transpi' ) . get_the_time( 'F, Y' ) . '</a>' . $after;
		} /** If montly Archives */
		elseif ( is_year() ) {
			$breadcrumb .= $before . '<a href="' . get_year_link( get_the_time( 'Y' ) ) . '">' . __( 'Archive for ', 'transpi' ) . get_the_time( 'Y' ) . '</a>' . $after;
		} /** If year Archives */
		elseif ( is_author() ) {
			$breadcrumb .= $before . '<a href="' . esc_url( get_author_posts_url( get_the_author_meta( "ID" ) ) ) . '">' . __( 'Archive for ', 'transpi' ) . get_the_author() . '</a>' . $after;
		} /** If author Archives */
		elseif ( is_search() ) {
			$breadcrumb .= $before . '' . esc_html__( 'Search Results for ', 'transpi' ) . get_search_query() . '' . $after;
		} /** if search template */
		elseif ( is_404() ) {
			$breadcrumb .= $before . '' . esc_html__( '404 - Not Found', 'transpi' ) . '' . $after;
			/** if search template */
		} elseif ( is_post_type_archive( 'product' ) ) {
			$shop_page_id = wc_get_page_id( 'shop' );
			if ( get_option( 'page_on_front' ) !== $shop_page_id ) {
				$shop_page = get_post( $shop_page_id );
				$_name     = wc_get_page_id( 'shop' ) ? get_the_title( wc_get_page_id( 'shop' ) ) : '';
				if ( ! $_name ) {
					$product_post_type = get_post_type_object( 'product' );
					$_name             = $product_post_type->labels->singular_name;
				}
				if ( is_search() ) {
					$breadcrumb .= $before . '<a href="' . get_post_type_archive_link( 'product' ) . '">' . $_name . '</a>' . $delimiter . esc_html__( 'Search results for &ldquo;', 'transpi' ) . get_search_query() . '&rdquo;' . $after;
				} elseif ( is_paged() ) {
					$breadcrumb .= $before . '<a href="' . get_post_type_archive_link( 'product' ) . '">' . $_name . '</a>' . $after;
				} else {
					$breadcrumb .= $before . $_name . $after;
				}
			}
		} else {
			$breadcrumb .= $before . '<a href="' . get_permalink() . '">' . wp_title() . '</a>' . $after;
		}
		/** Default value */
	}

	return $breadcrumb;
}

/**
 * Authore Avater
 */
function transpi_main_author_avatars($size) {
    echo get_avatar(get_the_author_meta('email'), $size);
}
  
add_action('genesis_entry_header', 'transpi_post_author_avatars');

/**
 * Search Widget
 */
function transpi_search_widgets( $form ) {
    $form = '<div class="search-widget"><div class="widget-area"><form role="search" method="get" id="searchform" class="search-input position-relative" action="' . home_url( '/' ) . '" >
    <input class="form_control" placeholder="' .esc_attr__( 'Search...', 'transpi' ) . '" type="text"  value="' . get_search_query() . '" name="s" id="s" />
    <button type="submit"><span class="icon fa fa-search"></span></button>
    </form></div></div>';
    return $form;
}
add_filter( 'get_search_form', 'transpi_search_widgets', 100 );

/**
 * Category Count Markup
 */
function transpi_category_html( $links ) {
    $links = str_replace( '</a> (', '<span class="cat-number">(', $links );
	$links = str_replace( ')', '</span></a>', $links );
    return $links;
}
add_filter( 'wp_list_categories', 'transpi_category_html' );

/**
 * transpi Archive Customiz
 *
 * @param   [type]  $links  [$links description]
 *
 * @return  [type]          [return description]
 */
function transpi_archive_html($links) {
    $links = str_replace('</a>&nbsp;(', '<span class="number">', $links);
    $links = str_replace(')', '</span></a>', $links);
    return $links;
}

add_filter('get_archives_link', 'transpi_archive_html');

/**
 * pagination
 */
if ( !function_exists( 'transpi_pagination' ) ) {

    function _transpi_pagi_callback( $pagination ) {
        return $pagination;
    }

    //page navegation
    function transpi_pagination( $prev, $next, $pages, $args ) {
        global $wp_query, $wp_rewrite;
        $menu = '';
        $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;

        if ( $pages == '' ) {
            global $wp_query;
            $pages = $wp_query->max_num_pages;

            if ( !$pages ) {
                $pages = 1;
            }

        }

        $pagination = [
            'base'      => add_query_arg( 'paged', '%#%' ),
            'format'    => '',
            'total'     => $pages,
            'current'   => $current,
            'prev_text' => $prev,
            'next_text' => $next,
            'type'      => 'array',
        ];

        //rewrite permalinks
        if ( $wp_rewrite->using_permalinks() ) {
            $pagination['base'] = user_trailingslashit( trailingslashit( remove_query_arg( 's', get_pagenum_link( 1 ) ) ) . 'page/%#%/', 'paged' );
        }

        if ( !empty( $wp_query->query_vars['s'] ) ) {
            $pagination['add_args'] = ['s' => get_query_var( 's' )];
        }

        $pagi = '';
        if ( paginate_links( $pagination ) != '' ) {
            $paginations = paginate_links( $pagination );
            $pagi .= '<ul class="styled-pagination text-center d-flex align-items-center justify-content-center mb-0 pl-0">';
            foreach ( $paginations as $key => $pg ) {
                $pagi .= '<li>' . $pg . '</li>';
            }
            $pagi .= '</ul>';
        }

        print _transpi_pagi_callback( $pagi );
    }
}

/**
 * Comment List Modification
 */

 function transpi_comments( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;?>

	<li  <?php comment_class('comment comments-content');?> id="comment-<?php comment_ID()?>">
        <div class="transpi-comment-item d-flex">
			<?php if ( get_avatar( $comment ) ) {?>
				<div class="transpi-comment-img">
					<?php echo get_avatar( $comment, 80 ); ?>
				</div>
			<?php }?>

			<div class="comments-text">
				<div class="trsp-comment__int-text">
					<div class="author-name-date">
						<span class="cmt-name"><?php comment_author_link()?></span>
						<span class="cmt-date"><?php echo esc_html(get_the_time( get_option('date_format')));?></span> 
					</div>
					<?php if ( $comment->comment_approved == '0' ): ?>
						<p><em><?php esc_html_e( 'Your comment is awaiting moderation.', 'transpi' );?></em></p>
					<?php endif;?>
					<?php comment_text();?>
				</div>
				<div class="cmt-reply position-absolute text-capitalize">
					<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'], 'reply_text' => wp_kses('Reply', true) ) ) );?>
				</div>
			</div>
        </div>
	</li>


<?php
}


/**
 * Comment Message Box
 */
function transpi_comment_reform( $arg ) {

	$arg['title_reply']   = esc_html__( 'Leave a comment', 'transpi' );
	$arg['comment_field'] = '<div class="row"><div class="col-lg-12 col-md-12 col-sm-12 form-group"><textarea id="comment" class="form_control" name="comment" cols="77" rows="3" placeholder="' . esc_attr__( "Comment", "transpi" ) . '" aria-required="true"></textarea></div></div>';

	return $arg;

}
add_filter( 'comment_form_defaults', 'transpi_comment_reform' );


/**
 * Comment Form Field
 */
function transpi_modify_comment_form_fields( $fields ) {
	$commenter = wp_get_current_commenter();
	$req       = get_option( 'require_name_email' );

	$fields['author'] = '<div class="row"><div class="col-lg-6 col-md-6 col-sm-12 form-group"><input type="text" name="author" id="author" value="' . esc_attr( $commenter['comment_author'] ) . '" placeholder="' . esc_attr__( "Name", "transpi" ) . '" size="22" tabindex="1"' . ( $req ? 'aria-required="true"' : '' ) . ' class="form_control" /></div>';

	$fields['email'] = '<div class="col-lg-6 col-md-6 col-sm-12 form-group"><input type="email" name="email" id="email" value="' . esc_attr( $commenter['comment_author_email'] ) . '" placeholder="' . esc_attr__( "Email", "transpi" ) . '" size="22" tabindex="2"' . ( $req ? 'aria-required="true"' : '' ) . ' class="form_control"  /></div>';

	$fields['url'] = '<div class="col-lg-12 col-md-12 col-sm-12 form-group"><input type="url" name="url" id="url" value="' . esc_attr( $commenter['comment_author_url'] ) . '" placeholder="' . esc_attr__( "Website", "transpi" ) . '" size="22" tabindex="2"' . ( $req ? 'aria-required="false"' : '' ) . ' class="form_control"  /></div></div>';

	return $fields;
}
add_filter( 'comment_form_default_fields', 'transpi_modify_comment_form_fields' );

// comment Move Field
function transpi_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}
add_filter( 'comment_form_fields', 'transpi_move_comment_field_to_bottom' );


/**
 * transpi Single Post Nav
 */
function transpi_single_post_pagination(){ 
    $transpi_prev_post = get_previous_post();
    $transpi_next_post = get_next_post();
?>

<div class="more-posts">
	<div class="d-flex justify-content-between align-items-center">
		<div class="prev-posts">
			<a href="<?php echo esc_url(get_the_permalink($transpi_prev_post));?>">
				<div class="post-image">
					<img src="<?php echo esc_url(get_the_post_thumbnail_url($transpi_prev_post, 'thumbnail'));?>" alt="<?php the_title_attribute();?>">
				</div>
				<h6><?php echo esc_html(wp_trim_words( get_the_title($transpi_prev_post), 3, '...' ));?></h6>
				<div class="text"><?php echo esc_html(wp_trim_words( get_the_excerpt($transpi_prev_post), 6, '' ));?></div>
			</a>
			
		</div>
		<div class="next-posts">
			<a href="<?php echo esc_url(get_the_permalink($transpi_next_post));?>">
				<div class="post-image">
					<img src="<?php echo esc_url(get_the_post_thumbnail_url($transpi_next_post, 'thumbnail'));?>" alt="<?php the_title_attribute();?>">
				</div>
				<h6><?php echo esc_html(wp_trim_words( get_the_title($transpi_next_post), 3, '...' ));?></h6>
				<div class="text"><?php echo esc_html(wp_trim_words( get_the_excerpt($transpi_next_post), 6, '' ));?></div>
			</a>
		</div>
	</div>
</div>
<?php 
}

/**
 * Product Per Page Count
 *
 * @param [type] $per_page
 * @return void
 */ 

 function transpi_product_count( $cols ) {
	$product_count = cs_get_option('product_count');
  $cols = !empty($product_count) ? $product_count : '12';
  return $cols;
}
add_filter( 'loop_shop_per_page', 'transpi_product_count', 20 );